==> fritzing_0.6.3b+dfsg.orig.tar.bz2: fritzing.2011.08.18.source/src/items/moduleidnames.cpp <==
/*******************************************************************

Part of the Fritzing project - http://fritzing.org
Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de

Fritzing is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fritzing is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.

********************************************************************

$Revision: 5302 $:
$Author: cohen@irascible.com $:
$Date: 2011-07-30 00:14:56 +0200 (Sat, 30 Jul 2011) $

********************************************************************/


#include "moduleidnames.h"


/////////////////////////////////

const QString ModuleIDNames::ModuleIDNameSuffix = "ModuleID";
const QString ModuleIDNames::RulerModuleIDName = "RulerModuleID";
const QString ModuleIDNames::BreadboardModuleIDName = "BreadboardModuleID";
const QString ModuleIDNames::TinyBreadboardModuleIDName = "TinyBreadboardModuleID";
const QString ModuleIDNames::RectangleModuleIDName = "RectanglePCBModuleID";
const QString ModuleIDNames::TwoSidedRectangleModuleIDName = "TwoLayerRectanglePCBModuleID";
const QString ModuleIDNames::NoteModuleIDName = "NoteModuleID";
const QString ModuleIDNames::WireModuleIDName = "WireModuleID";
const QString ModuleIDNames::JumperModuleIDName = "JumperModuleID";
const QString ModuleIDNames::GroundPlaneModuleIDName = "GroundPlaneModuleID";
const QString ModuleIDNames::GroundModuleIDName = "GroundModuleID";
const QString ModuleIDNames::PowerModuleIDName = "PowerModuleID";
const QString ModuleIDNames::JustPowerModuleIDName = "JustPowerModuleID";
const QString ModuleIDNames::ResistorModuleIDName = "ResistorModuleID";
const QString ModuleIDNames::LogoTextModuleIDName = "LogoTextModuleID";
const QString ModuleIDNames::LogoImageModuleIDName = "LogoImageModuleID";
const QString ModuleIDNames::Copper1LogoTextModuleIDName = "Copper1LogoTextModuleID";
const QString ModuleIDNames::Copper1LogoImageModuleIDName = "Copper1LogoImageModuleID";
const QString ModuleIDNames::Copper0LogoTextModuleIDName = "Copper0LogoTextModuleID";
const QString ModuleIDNames::Copper0LogoImageModuleIDName = "Copper0LogoImageModuleID";
const QString ModuleIDNames::HoleModuleIDName = "HoleModuleID";
const QString ModuleIDNames::ViaModuleIDName = "ViaModuleID";
const QString ModuleIDNames::CapacitorModuleIDName = "CapacitorModuleID";
const QString ModuleIDNames::CrystalModuleIDName = "CrystalModuleID";
const QString ModuleIDNames::ZenerDiodeModuleIDName = "ZenerDiodeModuleID";
const QString ModuleIDNames::ThermistorModuleIDName = "ThermistorModuleID";
const QString ModuleIDNames::PotentiometerModuleIDName = "PotentiometerModuleID";
const QString ModuleIDNames::InductorModuleIDName = "InductorModuleID";
const QString ModuleIDNames::LEDModuleIDName = "LEDModuleID";
const QString ModuleIDNames::ColorLEDModuleIDName = "ColorLEDModuleID";
const QString ModuleIDNames::PerfboardModuleIDName = "PerfboardModuleID";
const QString ModuleIDNames::StripboardModuleIDName = "StripboardModuleID";
const QString ModuleIDNames::SpacerModuleIDName = "__spacer__";
const QString ModuleIDNames::SchematicFrameModuleIDName = "SchematicFrameModuleID";

==> fritzing_0.7.4b+dfsg.orig.tar.bz2: fritzing-0.7.4b.source/src/items/moduleidnames.cpp <==
/*******************************************************************

Part of the Fritzing project - http://fritzing.org
Copyright (c) 2007-2011 Fachhochschule Potsdam - http://fh-potsdam.de

Fritzing is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fritzing is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.

********************************************************************

$Revision: 5857 $:
$Author: cohen@irascible.com $:
$Date: 2012-02-12 18:16:07 +0100 (Sun, 12 Feb 2012) $

********************************************************************/


#include "moduleidnames.h"


/////////////////////////////////

const QString ModuleIDNames::ModuleIDNameSuffix = "ModuleID";
const QString ModuleIDNames::RulerModuleIDName = "RulerModuleID";
const QString ModuleIDNames::BreadboardModuleIDName = "BreadboardModuleID";
const QString ModuleIDNames::TinyBreadboardModuleIDName = "TinyBreadboardModuleID";
const QString ModuleIDNames::RectangleModuleIDName = "RectanglePCBModuleID";
const QString ModuleIDNames::TwoSidedRectangleModuleIDName = "TwoLayerRectanglePCBModuleID";
const QString ModuleIDNames::NoteModuleIDName = "NoteModuleID";
const QString ModuleIDNames::WireModuleIDName = "WireModuleID";
const QString ModuleIDNames::JumperModuleIDName = "JumperModuleID";
const QString ModuleIDNames::GroundPlaneModuleIDName = "GroundPlaneModuleID";
const QString ModuleIDNames::GroundModuleIDName = "GroundModuleID";
const QString ModuleIDNames::PowerModuleIDName = "PowerModuleID";
const QString ModuleIDNames::JustPowerModuleIDName = "JustPowerModuleID";
const QString ModuleIDNames::ResistorModuleIDName = "ResistorModuleID";
const QString ModuleIDNames::LogoTextModuleIDName = "LogoTextModuleID";
const QString ModuleIDNames::LogoImageModuleIDName = "LogoImageModuleID";
const QString ModuleIDNames::Copper1LogoTextModuleIDName = "Copper1LogoTextModuleID";
const QString ModuleIDNames::Copper1LogoImageModuleIDName = "Copper1LogoImageModuleID";
const QString ModuleIDNames::Copper0LogoTextModuleIDName = "Copper0LogoTextModuleID";
const QString ModuleIDNames::Copper0LogoImageModuleIDName = "Copper0LogoImageModuleID";
const QString ModuleIDNames::HoleModuleIDName = "HoleModuleID";
const QString ModuleIDNames::ViaModuleIDName = "ViaModuleID";
const QString ModuleIDNames::PadModuleIDName = "PadModuleID";
const QString ModuleIDNames::CapacitorModuleIDName = "CapacitorModuleID";
const QString ModuleIDNames::CrystalModuleIDName = "CrystalModuleID";
const QString ModuleIDNames::ZenerDiodeModuleIDName = "ZenerDiodeModuleID";
const QString ModuleIDNames::ThermistorModuleIDName = "ThermistorModuleID";
const QString ModuleIDNames::PotentiometerModuleIDName = "PotentiometerModuleID";
const QString ModuleIDNames::InductorModuleIDName = "InductorModuleID";
const QString ModuleIDNames::LEDModuleIDName = "LEDModuleID";
const QString ModuleIDNames::ColorFluxLEDModuleIDName = "LEDSuperfluxModuleID";
const QString ModuleIDNames::ColorLEDModuleIDName = "ColorLEDModuleID";
const QString ModuleIDNames::PerfboardModuleIDName = "PerfboardModuleID";
const QString ModuleIDNames::StripboardModuleIDName = "StripboardModuleID";
const QString ModuleIDNames::SpacerModuleIDName = "__spacer__";
const QString ModuleIDNames::SchematicFrameModuleIDName = "SchematicFrameModuleID";
